@@ -1,7 +1,7 @@
 /**************************************************************************
-        This file is part of KitchenAlert v.0.09
+        This file is part of KitchenAlert
 
-        Copyright (C) 2010  Heli Hyvättinen
+        Copyright (C) 2010-2011  Heli Hyvättinen
 
         Kitchen Alert is free software: you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -29,12 +29,12 @@
 
 
 
+
+
 AlertSound::AlertSound(QObject *parent) :
     QObject(parent)
 {
 
-    //THIS NEEDS TESTING: DOES IT REALLY CHANGE TUNE WHEN RESTARTING THE APPLICATION?
-
     defaultsound_ = "/home/opt/KitchenAlert/DoorbellModifiedFinal.mp3";
     QString filename;
 
@@ -52,7 +52,11 @@ AlertSound::AlertSound(QObject *parent) :
     {
         filename = settings.value("soundfile",defaultsound_).toString();
     }
-    pSound_ = Phonon::createPlayer(Phonon::MusicCategory, Phonon::MediaSource(filename));
+
+
+
+      pSound_ = new QMediaPlayer;
+      pSound_->setMedia(QUrl::fromLocalFile(filename));
 }
 
 AlertSound::~AlertSound()
@@ -66,32 +70,28 @@ AlertSound::~AlertSound()
 
 void AlertSound::play()
 {
-    pSound_->stop(); //Just testing if stopping the previous alert will prevent the jammming of the sound (only partially, but since it helped some, keeping it even if the problem was solved otherwise)
-    pSound_->play();
-    qDebug() << "Sound should be played now";
+     pSound_->play();
+  //  qDebug() << "Sound should be played now";
 }
 
 void AlertSound::stop()
 {
 
     pSound_->stop();
-    qDebug() << pSound_->state();
-    qDebug() << "Sound stopped by AlertSound.";
+//    qDebug() << pSound_->state();
+//    qDebug() << "Sound stopped by AlertSound.";
 }
 
 
 
 void AlertSound::setSound(QString filename)
 {
-   QSettings settings("KitchenAlert","KitchenAlert");
-   settings.setValue("UseDefaultSound",false);
-   settings.setValue("soundfile",filename);
-   pSound_->setCurrentSource(filename);
+
+   pSound_->setMedia(QUrl::fromLocalFile(filename));
 }
 
 void AlertSound::setDefaultSound()
 {
-    QSettings settings ("KitchenAlert","KitchenAlert");
-    settings.setValue("UseDefaultSound",true);
-    pSound_->setCurrentSource(defaultsound_);
+
+    pSound_->setMedia(QUrl::fromLocalFile(defaultsound_));
 }
