@@ -1,7 +1,7 @@
 /**************************************************************************
         KitchenAlert
 
-        Copyright (C) 2010  Heli Hyvättinen
+        Copyright (C) 2010-2011  Heli Hyvättinen
 
         This file is part of KitchenAlert.
 
@@ -29,16 +29,14 @@
 
 #include <QObject>
 
-
-
-#include <Phonon>
+#include <QMediaPlayer>
 
 
 /*! Class for playing the alert sound'
 
   @author Heli Hyvättinen
-  @date 2010-09-27
-  @version 0.2.0
+  @date 2011-03-29
+  @version 0.2.1
 
 Class for playing (and stopping) the alert sound.
 
@@ -71,8 +69,8 @@ private:
 
 
 
-    Phonon::MediaObject *pSound_;
-    QString defaultsound_;
+   QMediaPlayer *pSound_;
+   QString defaultsound_;
 
 
 };
