@@ -2,7 +2,7 @@
 
         KitchenAlert
 
-        Copyright (C) 2010  Heli Hyvättinen
+        Copyright (C) 2010-2011  Heli Hyvättinen
 
         This file is part of KitchenAlert.
 
@@ -286,10 +286,22 @@ void KitchenAlertMainWindow::openSelectSoundDialog()
     SelectSoundDialog dialog;
    if ( dialog.exec() == QDialog::Accepted) //if user pressed OK
     {
+       QSettings settings ("KitchenAlert","KitchenAlert");
+      
        if (dialog.isDefaultSoundChecked() == true)
+       { 
+	 
+	   settings.setValue("UseDefaultSound",true); 
            emit defaultSoundEnabled();
-       else
-           emit soundChanged(dialog.getSoundFileName());
+       }   
+      else
+       {
+           QString filename = dialog.getSoundFileName();
+           settings.setValue("UseDefaultSound",false);
+           settings.setValue("soundfile",filename);
+           emit soundChanged(filename);
+       }
+
     }
 
 }
@@ -297,7 +309,7 @@ void KitchenAlertMainWindow::openSelectSoundDialog()
 void KitchenAlertMainWindow::openAbout()
 {
     QMessageBox::about(this,tr("About KitchenAlert"),tr("<p>Version %1"
-                                                        "<p>Copyright &copy; Heli Hyv&auml;ttinen 2010"
+                                                        "<p>Copyright &copy; Heli Hyv&auml;ttinen 2010-2011"
                                                          "<p>License: General Public License v3"
                                                          "<p>Web page: http://kitchenalert.garage.maemo.org/"
                                                          "<p>Bugtracker: https://garage.maemo.org/projects/kitchenalert/").arg(QApplication::applicationVersion()));
