@@ -28,8 +28,8 @@
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
-    a.setApplicationName("KitchenAlert"); //a name is required by phonon
-    a.setApplicationVersion("0.2.0");
+    a.setApplicationName("KitchenAlert"); //a name is required to connect to DBus
+    a.setApplicationVersion("0.2.1");
     a.setOrganizationName("KitchenAlert");
     KitchenAlertMainWindow w;
 #if defined(Q_WS_S60)
